@@ -48,12 +48,14 @@ def my_hook(t):
         bsize  : int, optional
             Size of each block (in tqdm units) [default: 1].
         tsize  : int, optional
-            Total size (in tqdm units). If [default: None] remains unchanged.
+            Total size (in tqdm units). If [default: None] or -1,
+            remains unchanged.
         """
-        if tsize is not None:
+        if tsize not in (None, -1):
             t.total = tsize
         t.update((b - last_b[0]) * bsize)
         last_b[0] = b
+
     return update_to
 
 
@@ -65,6 +67,7 @@ class TqdmUpTo(tqdm):
     Inspired by [twine#242](https://github.com/pypa/twine/pull/242),
     [here](https://github.com/pypa/twine/commit/42e55e06).
     """
+
     def update_to(self, b=1, bsize=1, tsize=None):
         """
         b  : int, optional
@@ -90,5 +93,5 @@ eg_out = opts['--output'].replace("/dev/null", devnull)
 #                        reporthook=my_hook(t), data=None)
 with TqdmUpTo(unit='B', unit_scale=True, unit_divisor=1024, miniters=1,
               desc=eg_file) as t:  # all optional kwargs
-    urllib.urlretrieve(eg_link, filename=eg_out,
-                       reporthook=t.update_to, data=None)
+    urllib.urlretrieve(eg_link, filename=eg_out, reporthook=t.update_to,
+                       data=None)
