@@ -33,12 +33,12 @@ def test_pandas_rolling_expanding():
         tqdm.pandas(file=our_file, leave=True, ascii=True)
 
         series = pd.Series(randint(0, 50, (123,)))
-        res1 = series.rolling(10).progress_apply(lambda x: 1)
-        res2 = series.rolling(10).apply(lambda x: 1)
+        res1 = series.rolling(10).progress_apply(lambda x: 1, raw=True)
+        res2 = series.rolling(10).apply(lambda x: 1, raw=True)
         assert res1.equals(res2)
 
-        res3 = series.expanding(10).progress_apply(lambda x: 2)
-        res4 = series.expanding(10).apply(lambda x: 2)
+        res3 = series.expanding(10).progress_apply(lambda x: 2, raw=True)
+        res4 = series.expanding(10).apply(lambda x: 2, raw=True)
         assert res3.equals(res4)
 
         expects = ['114it']  # 123-10+1
@@ -104,7 +104,7 @@ def test_pandas_data_frame():
         assert res1.equals(res2)
 
         # apply
-        for axis in [0, 1]:
+        for axis in [0, 1, 'index', 'columns']:
             res3 = df.progress_apply(task_func, axis=axis)
             res4 = df.apply(task_func, axis=axis)
             assert res3.equals(res4)
@@ -130,7 +130,7 @@ def test_pandas_data_frame():
 def test_pandas_groupby_apply():
     """Test pandas.DataFrame.groupby(...).progress_apply"""
     try:
-        from numpy.random import randint
+        from numpy.random import randint, rand
         import pandas as pd
     except ImportError:
         raise SkipTest
@@ -144,6 +144,11 @@ def test_pandas_groupby_apply():
         dfs = pd.DataFrame(randint(0, 50, (500, 3)), columns=list('abc'))
         dfs.groupby(['a']).progress_apply(lambda x: None)
 
+        df2 = df = pd.DataFrame(dict(a=randint(1, 8, 10000), b=rand(10000)))
+        res1 = df2.groupby("a").apply(max)
+        res2 = df2.groupby("a").progress_apply(max)
+        assert res1.equals(res2)
+
         our_file.seek(0)
 
         # don't expect final output since no `leave` and
