@@ -1,5 +1,5 @@
 from __future__ import division
-from tqdm import tqdm, TMonitor
+from tqdm import tqdm, trange, TMonitor
 from tests_tqdm import with_setup, pretest, posttest, SkipTest, \
     StringIO, closing
 from tests_tqdm import DiscreteTimer, cpu_timify
@@ -41,6 +41,13 @@ def incr(x):
     return x + 1
 
 
+def incr_bar(x):
+    with closing(StringIO()) as our_file:
+        for _ in trange(x, lock_args=(False,), file=our_file):
+            pass
+    return incr(x)
+
+
 @with_setup(pretest, posttest)
 def test_monitor_thread():
     """Test dummy monitoring thread"""
@@ -109,7 +116,7 @@ def test_monitoring_and_cleanup():
             timer.sleep(maxinterval * 2)
             t.update(2)
             timeend = timer.time()
-            while not (t.monitor.woken >= timeend):
+            while t.monitor.woken < timeend:
                 timer.sleep(1)  # Force monitor to wake up if it woken too soon
                 sleep(0.000001)
             # Wait for the monitor to get out of sleep's loop and update tqdm..
@@ -179,3 +186,18 @@ def test_imap():
     pool = Pool()
     res = list(tqdm(pool.imap(incr, range(100)), disable=True))
     assert res[-1] == 100
+
+
+@with_setup(pretest, posttest)
+def test_threadpool():
+    """Test concurrent.futures.ThreadPoolExecutor"""
+    try:
+        from concurrent.futures import ThreadPoolExecutor
+        from threading import RLock
+    except ImportError:
+        raise SkipTest
+
+    tqdm.set_lock(RLock())
+    with ThreadPoolExecutor(8) as pool:
+        res = list(tqdm(pool.map(incr_bar, range(100)), disable=True))
+    assert sum(res) == sum(range(1, 101))
